pub enum TemplateReference {
Preset(TemplatePreset),
Uri(String),
}Expand description
A reference to a template, which can be either a named builtin preset
or a URI (e.g., file://..., @hub/..., https://...).
Variants
Preset(TemplatePreset)
A named builtin template preset.
Uri(String)
A URI reference to a remote or local template.
Implementations
Sourceimpl TemplateReference
impl TemplateReference
Sourcepub fn citation_template(&self) -> Option<Vec<TemplateComponent>>
pub fn citation_template(&self) -> Option<Vec<TemplateComponent>>
Resolve this reference to a citation template when it names a built-in preset.
Sourcepub fn bibliography_template(&self) -> Option<Vec<TemplateComponent>>
pub fn bibliography_template(&self) -> Option<Vec<TemplateComponent>>
Resolve this reference to a bibliography template when it names a built-in preset.