pub enum TemplateVariant {
Full(Vec<TemplateComponent>),
Diff(TemplateVariantDiff),
}Expand description
Type-specific template override, either as a complete legacy template or a V3 diff.
Variants
Full(Vec<TemplateComponent>)
Complete replacement template used by Template V1/V2 styles.
Diff(TemplateVariantDiff)
Structural diff applied to a parent template during style resolution.
Implementations
Sourceimpl TemplateVariant
impl TemplateVariant
Sourcepub fn as_template(&self) -> Option<&[TemplateComponent]>
pub fn as_template(&self) -> Option<&[TemplateComponent]>
Return this variant as a concrete template if it has already been resolved.
Sourcepub fn as_template_mut(&mut self) -> Option<&mut Vec<TemplateComponent>>
pub fn as_template_mut(&mut self) -> Option<&mut Vec<TemplateComponent>>
Return this variant as a mutable concrete template if it has already been resolved.
Sourcepub fn into_template(self) -> Option<Vec<TemplateComponent>>
pub fn into_template(self) -> Option<Vec<TemplateComponent>>
Convert this variant into its concrete template if it has already been resolved.