pub enum NoteMarkerOrder {
Before,
After,
}Expand description
Controls whether a note marker appears before or after adjacent movable punctuation.
Variants
Before
Place the note marker before the closest movable punctuation mark.
After
Place the note marker after the closest movable punctuation mark.