pub enum NoteNumberPlacement {
Inside,
Outside,
Same,
}Expand description
Controls where a footnote number marker is placed relative to closing quotation marks.
Variants
Inside
Place the note marker inside the closing quotation mark.
Outside
Place the note marker outside the closing quotation mark.
Same
Place the note marker on the same side as the movable punctuation when only one side has punctuation; otherwise default to outside.