pub struct ScriptConfig {
pub use_native_ordering: bool,
pub delimiter: Option<String>,
pub sort_separator: Option<String>,
}Expand description
Configuration for specific scripts.
Fields
use_native_ordering: boolWhether to use native ordering for this script (e.g., FamilyGiven for CJK).
delimiter: Option<String>Custom delimiter between name parts for this script.
sort_separator: Option<String>Custom delimiter between family and given name when this script is inverted.