pub struct Sort {
pub shorten_names: bool,
pub render_substitutions: bool,
pub template: Vec<SortSpec>,
}Expand description
Sorting configuration.
Specifies how bibliography entries are ordered.
Fields
shorten_names: boolWhether to shorten name lists for sorting the same as for display.
render_substitutions: boolWhether to apply the same name substitutions during sorting as during rendering.
template: Vec<SortSpec>Sort keys in order of application.