pub struct GroupSort {
pub template: Vec<GroupSortKey>,
}Expand description
Per-group sorting specification.
Sorting follows a template of sort keys, applied in order. The first key is the primary sort, second is the tiebreaker, etc.
Fields
template: Vec<GroupSortKey>Ordered list of sort keys to apply.